@@ -36,17 +36,21 @@ class VFCode:
         :param draw_lines: 是否画干扰线
         :param lines_width: 干扰线宽度
         :param mask: 是否使用磨砂效果
-        :param font: 字体 (linux系统添加字体文件 /usr/share/fonts/arial.ttf)
+        :param font: 字体 内置可选字体 arial.ttf calibri.ttf simsun.ttc
         """
         self.code = None
         self._img = None
         self.width = width
         self.height = height
         self.fontsize = fontsize
+        # linux添加字体文件 /usr/share/fonts/arial.ttf
         if font is None:
-            self.font = ImageFont.truetype(Path(__file__).resolve().parent / 'fonts/arial.ttf', fontsize)
+            self.font = ImageFont.truetype(str(Path(__file__).resolve().parent / 'fonts/arial.ttf'), fontsize)
         else:
-            self.font = ImageFont.truetype(font, fontsize)
+            try:
+                self.font = ImageFont.truetype(str(Path(__file__).resolve().parent / 'fonts/%s'%font), fontsize)
+            except:
+                self.font = ImageFont.truetype(font, fontsize)
         self.draw_dots = draw_dots
         self.dots_width = dots_width
         self.draw_lines = draw_lines
